@@ -3,7 +3,7 @@ package Function::Return;
 use v5.14.0;
 use warnings;
 
-our $VERSION = "0.13";
+our $VERSION = "0.14";
 
 use Attribute::Handlers;
 use B::Hooks::EndOfScope;
@@ -138,7 +138,7 @@ sub _register_submeta {
     my ($class, $pkg, $sub, $types) = @_;
 
     my $meta = Sub::Meta->new(sub => $sub, stashname => $pkg);
-    $meta->set_returns(list => $types);
+    $meta->set_returns(_normalize_types($types));
 
     if (my $materials = Sub::Meta::Finder::FunctionParameters::find_materials($sub)) {
         $meta->set_is_method($materials->{is_method});
@@ -156,7 +156,7 @@ sub _register_submeta_and_install {
     my $wrapped  = $class->wrap_sub($sub, $types);
 
     my $meta = Sub::Meta->new(sub => $wrapped, stashname => $pkg);
-    $meta->set_returns(list => $types);
+    $meta->set_returns(_normalize_types($types));
 
     if (my $materials = Sub::Meta::Finder::FunctionParameters::find_materials($sub)) {
         $meta->set_is_method($materials->{is_method});
@@ -174,6 +174,16 @@ sub _register_submeta_and_install {
     return;
 }
 
+sub _normalize_types {
+    my $types = shift;
+    if (@$types == 1) {
+        return $types->[0];
+    }
+    else {
+        return $types;
+    }
+}
+
 1;
 __END__
 
